@@ -59,12 +59,15 @@ signals:
 protected:
 	virtual bool preStart();
 	virtual bool nextLine(const QString &line);
+	/**
+	 * @brief needed to submit the last search result
+	 */
 	virtual void finish();
 
 private:
 	QStringList m_keyLines;		///< the lines belonging to one key
 	int m_patternPos;
-	int m_count;			///< how many pages of output were requested
+	bool m_pageEmpty;		///< if the current page of output is empty
 };
 
 #endif // KGPGUIDTRANSACTION_H
